@@ -54,14 +54,14 @@ vteseq_n_hash::hash (register const char *str, register unsigned int len)
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
-      131, 131, 131, 131, 131,   0,  31, 131, 131,  36,
+      131, 131, 131, 131, 131,   0,  31, 131, 131,  49,
        33, 131, 131, 131, 131,   2, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131,   9,   3,   0,
-       53,   0,  13,  17,   8,  30,  19,  46,  31,  22,
-       33,   0,   6,   1,  24,   9,  22,   4,  62, 131,
+       53,   0,  13,  20,   8,  30,  23,  43,  31,  22,
+       33,   0,   6,   1,  24,   9,  22,   4,  34, 131,
         0, 131,   0, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
       131, 131, 131, 131, 131, 131, 131, 131, 131, 131,
@@ -163,16 +163,17 @@ struct vteseq_n_pool_t
     char vteseq_n_pool_str56[sizeof("change-foreground-color-bel")];
     char vteseq_n_pool_str57[sizeof("set-scrolling-region-to-end")];
     char vteseq_n_pool_str58[sizeof("set-icon-and-window-title")];
-    char vteseq_n_pool_str59[sizeof("reset-cursor-background-color")];
+    char vteseq_n_pool_str59[sizeof("normal-keypad")];
     char vteseq_n_pool_str60[sizeof("send-primary-device-attributes")];
     char vteseq_n_pool_str61[sizeof("set-scrolling-region-from-start")];
-    char vteseq_n_pool_str62[sizeof("normal-keypad")];
+    char vteseq_n_pool_str62[sizeof("reset-cursor-background-color")];
+    char vteseq_n_pool_str63[sizeof("device-status-report")];
     char vteseq_n_pool_str64[sizeof("scroll-down")];
     char vteseq_n_pool_str65[sizeof("delete-lines")];
     char vteseq_n_pool_str66[sizeof("request-terminal-parameters")];
     char vteseq_n_pool_str67[sizeof("line-position-absolute")];
     char vteseq_n_pool_str68[sizeof("cursor-down")];
-    char vteseq_n_pool_str69[sizeof("iterm2-1337")];
+    char vteseq_n_pool_str69[sizeof("send-secondary-device-attributes")];
     char vteseq_n_pool_str70[sizeof("erase-in-line")];
     char vteseq_n_pool_str71[sizeof("save-mode")];
     char vteseq_n_pool_str72[sizeof("window-manipulation")];
@@ -184,19 +185,19 @@ struct vteseq_n_pool_t
     char vteseq_n_pool_str78[sizeof("change-highlight-background-color-bel")];
     char vteseq_n_pool_str79[sizeof("set-current-file-uri")];
     char vteseq_n_pool_str80[sizeof("designate-g1-line-drawing")];
-    char vteseq_n_pool_str81[sizeof("reset-highlight-foreground-color")];
-    char vteseq_n_pool_str83[sizeof("designate-g0-line-drawing")];
+    char vteseq_n_pool_str81[sizeof("iterm2-133")];
+    char vteseq_n_pool_str82[sizeof("iterm2-1337")];
     char vteseq_n_pool_str84[sizeof("cursor-next-line")];
-    char vteseq_n_pool_str85[sizeof("return-terminal-status")];
+    char vteseq_n_pool_str85[sizeof("reset-highlight-foreground-color")];
     char vteseq_n_pool_str87[sizeof("change-highlight-foreground-color-st")];
     char vteseq_n_pool_str88[sizeof("change-highlight-foreground-color-bel")];
-    char vteseq_n_pool_str90[sizeof("reset-highlight-background-color")];
-    char vteseq_n_pool_str91[sizeof("device-status-report")];
+    char vteseq_n_pool_str89[sizeof("return-terminal-status")];
+    char vteseq_n_pool_str90[sizeof("change-cursor-background-color-st")];
+    char vteseq_n_pool_str91[sizeof("change-cursor-background-color-bel")];
     char vteseq_n_pool_str92[sizeof("linux-console-cursor-attributes")];
-    char vteseq_n_pool_str93[sizeof("change-cursor-background-color-st")];
-    char vteseq_n_pool_str94[sizeof("change-cursor-background-color-bel")];
+    char vteseq_n_pool_str94[sizeof("reset-highlight-background-color")];
     char vteseq_n_pool_str95[sizeof("erase-in-display")];
-    char vteseq_n_pool_str97[sizeof("send-secondary-device-attributes")];
+    char vteseq_n_pool_str96[sizeof("designate-g0-line-drawing")];
     char vteseq_n_pool_str98[sizeof("insert-lines")];
     char vteseq_n_pool_str99[sizeof("insert-blank-characters")];
     char vteseq_n_pool_str101[sizeof("erase-characters")];
@@ -204,9 +205,9 @@ struct vteseq_n_pool_t
     char vteseq_n_pool_str105[sizeof("designate-g1-british")];
     char vteseq_n_pool_str106[sizeof("designate-g1-plain")];
     char vteseq_n_pool_str107[sizeof("set-current-hyperlink")];
-    char vteseq_n_pool_str108[sizeof("designate-g0-british")];
-    char vteseq_n_pool_str109[sizeof("designate-g0-plain")];
-    char vteseq_n_pool_str112[sizeof("return-terminal-id")];
+    char vteseq_n_pool_str116[sizeof("return-terminal-id")];
+    char vteseq_n_pool_str121[sizeof("designate-g0-british")];
+    char vteseq_n_pool_str122[sizeof("designate-g0-plain")];
     char vteseq_n_pool_str130[sizeof("application-keypad")];
   };
 static const struct vteseq_n_pool_t vteseq_n_pool_contents =
@@ -262,16 +263,17 @@ static const struct vteseq_n_pool_t vteseq_n_pool_contents =
     "change-foreground-color-bel",
     "set-scrolling-region-to-end",
     "set-icon-and-window-title",
-    "reset-cursor-background-color",
+    "normal-keypad",
     "send-primary-device-attributes",
     "set-scrolling-region-from-start",
-    "normal-keypad",
+    "reset-cursor-background-color",
+    "device-status-report",
     "scroll-down",
     "delete-lines",
     "request-terminal-parameters",
     "line-position-absolute",
     "cursor-down",
-    "iterm2-1337",
+    "send-secondary-device-attributes",
     "erase-in-line",
     "save-mode",
     "window-manipulation",
@@ -283,19 +285,19 @@ static const struct vteseq_n_pool_t vteseq_n_pool_contents =
     "change-highlight-background-color-bel",
     "set-current-file-uri",
     "designate-g1-line-drawing",
-    "reset-highlight-foreground-color",
-    "designate-g0-line-drawing",
+    "iterm2-133",
+    "iterm2-1337",
     "cursor-next-line",
-    "return-terminal-status",
+    "reset-highlight-foreground-color",
     "change-highlight-foreground-color-st",
     "change-highlight-foreground-color-bel",
-    "reset-highlight-background-color",
-    "device-status-report",
-    "linux-console-cursor-attributes",
+    "return-terminal-status",
     "change-cursor-background-color-st",
     "change-cursor-background-color-bel",
+    "linux-console-cursor-attributes",
+    "reset-highlight-background-color",
     "erase-in-display",
-    "send-secondary-device-attributes",
+    "designate-g0-line-drawing",
     "insert-lines",
     "insert-blank-characters",
     "erase-characters",
@@ -303,9 +305,9 @@ static const struct vteseq_n_pool_t vteseq_n_pool_contents =
     "designate-g1-british",
     "designate-g1-plain",
     "set-current-hyperlink",
+    "return-terminal-id",
     "designate-g0-british",
     "designate-g0-plain",
-    "return-terminal-id",
     "application-keypad"
   };
 #define vteseq_n_pool ((const char *) &vteseq_n_pool_contents)
@@ -314,7 +316,7 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
 {
   enum
     {
-      TOTAL_KEYWORDS = 96,
+      TOTAL_KEYWORDS = 97,
       MIN_WORD_LENGTH = 3,
       MAX_WORD_LENGTH = 37,
       MIN_HASH_VALUE = 3,
@@ -327,11 +329,11 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
        0,  0,  7,  9,  9, 10, 17,  9, 15, 10,  0, 12, 13,  9,
       15, 15,  8, 22, 15, 16, 14,  9, 14, 23,  5,  9, 22, 25,
        9, 12, 11, 26, 27, 16, 25,  8, 20, 14, 21, 15, 20, 26,
-      27, 27, 25, 29, 30, 31, 13,  0, 11, 12, 27, 22, 11, 11,
-      13,  9, 19, 16, 27, 21, 24, 36, 37, 20, 25, 32,  0, 25,
-      16, 22,  0, 36, 37,  0, 32, 20, 31, 33, 34, 16,  0, 32,
-      12, 23,  0, 16, 25,  0,  0, 20, 18, 21, 20, 18,  0,  0,
-      18,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
+      27, 27, 25, 13, 30, 31, 29, 20, 11, 12, 27, 22, 11, 32,
+      13,  9, 19, 16, 27, 21, 24, 36, 37, 20, 25, 10, 11,  0,
+      16, 32,  0, 36, 37, 22, 33, 34, 31,  0, 32, 16, 25,  0,
+      12, 23,  0, 16, 25,  0,  0, 20, 18, 21,  0,  0,  0,  0,
+       0,  0,  0,  0, 18,  0,  0,  0,  0, 20, 18,  0,  0,  0,
        0,  0,  0,  0, 18
     };
   static const struct vteseq_n_struct wordlist[] =
@@ -443,15 +445,16 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str57, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_scrolling_region_to_end)},
 #line 143 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str58, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_icon_and_window_title)},
-#line 91 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str59, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_cursor_background_color)},
+#line 60 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str59, VTE_SEQUENCE_HANDLER(vte_sequence_handler_normal_keypad)},
 #line 161 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str60, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_primary_device_attributes)},
 #line 95 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str61, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_scrolling_region_from_start)},
-#line 60 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str62, VTE_SEQUENCE_HANDLER(vte_sequence_handler_normal_keypad)},
-      {-1},
+#line 91 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str62, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_cursor_background_color)},
+#line 93 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str63, VTE_SEQUENCE_HANDLER(vte_sequence_handler_device_status_report)},
 #line 48 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str64, VTE_SEQUENCE_HANDLER(vte_sequence_handler_scroll_down)},
 #line 52 "vteseq-n.gperf"
@@ -462,8 +465,8 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str67, VTE_SEQUENCE_HANDLER(vte_sequence_handler_line_position_absolute)},
 #line 45 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str68, VTE_SEQUENCE_HANDLER(vte_sequence_handler_cursor_down)},
-#line 174 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str69, VTE_SEQUENCE_HANDLER(vte_sequence_handler_iterm2_1337)},
+#line 163 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str69, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_secondary_device_attributes)},
 #line 58 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str70, VTE_SEQUENCE_HANDLER(vte_sequence_handler_erase_in_line)},
 #line 38 "vteseq-n.gperf"
@@ -486,36 +489,36 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str79, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_current_file_uri)},
 #line 127 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str80, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_line_drawing)},
-#line 113 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str81, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_foreground_color)},
+#line 174 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str81, VTE_SEQUENCE_HANDLER(vte_sequence_handler_iterm2_133)},
+#line 175 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str82, VTE_SEQUENCE_HANDLER(vte_sequence_handler_iterm2_1337)},
       {-1},
-#line 124 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str83, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_line_drawing)},
 #line 76 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str84, VTE_SEQUENCE_HANDLER(vte_sequence_handler_cursor_next_line)},
-#line 107 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str85, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_status)},
+#line 113 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str85, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_foreground_color)},
       {-1},
 #line 112 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str87, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_highlight_foreground_color_st)},
 #line 111 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str88, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_highlight_foreground_color_bel)},
-      {-1},
-#line 110 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str90, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_background_color)},
-#line 93 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str91, VTE_SEQUENCE_HANDLER(vte_sequence_handler_device_status_report)},
+#line 107 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str89, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_status)},
+#line 90 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str90, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_cursor_background_color_st)},
+#line 89 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str91, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_cursor_background_color_bel)},
 #line 162 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str92, VTE_SEQUENCE_HANDLER(vte_sequence_handler_linux_console_cursor_attributes)},
-#line 90 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str93, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_cursor_background_color_st)},
-#line 89 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str94, VTE_SEQUENCE_HANDLER(vte_sequence_handler_change_cursor_background_color_bel)},
+      {-1},
+#line 110 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str94, VTE_SEQUENCE_HANDLER(vte_sequence_handler_reset_highlight_background_color)},
 #line 78 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str95, VTE_SEQUENCE_HANDLER(vte_sequence_handler_erase_in_display)},
+#line 124 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str96, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_line_drawing)},
       {-1},
-#line 163 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str97, VTE_SEQUENCE_HANDLER(vte_sequence_handler_send_secondary_device_attributes)},
 #line 54 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str98, VTE_SEQUENCE_HANDLER(vte_sequence_handler_insert_lines)},
 #line 115 "vteseq-n.gperf"
@@ -532,15 +535,15 @@ vteseq_n_hash::lookup (register const char *str, register unsigned int len)
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str106, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g1_plain)},
 #line 172 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str107, VTE_SEQUENCE_HANDLER(vte_sequence_handler_set_current_hyperlink)},
-#line 125 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str108, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_british)},
-#line 123 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str109, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_plain)},
-      {-1}, {-1},
-#line 85 "vteseq-n.gperf"
-      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str112, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_id)},
-      {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
       {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
+#line 85 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str116, VTE_SEQUENCE_HANDLER(vte_sequence_handler_return_terminal_id)},
+      {-1}, {-1}, {-1}, {-1},
+#line 125 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str121, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_british)},
+#line 123 "vteseq-n.gperf"
+      {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str122, VTE_SEQUENCE_HANDLER(vte_sequence_handler_designate_g0_plain)},
+      {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 83 "vteseq-n.gperf"
       {(int)(long)&((struct vteseq_n_pool_t *)0)->vteseq_n_pool_str130, VTE_SEQUENCE_HANDLER(vte_sequence_handler_application_keypad)}
     };
